==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/hi.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "लाइटबॉक्स गैलरी मापदंडों का प्रबंधन");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "गैलरी प्रबंधित");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "पूर्ण आकार छवि चौड़ाई");
define('MANAGE_GALLERY_FULL_HEIGHT', "पूर्ण आकार छवि ऊंचाई");
define('MANAGE_GALLERY_THUMB_WIDTH', "थंबनेल छवि चौड़ाई");
define('MANAGE_GALLERY_THUMB_HEIGHT', "थंबनेल छवि ऊंचाई");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "रक्षित अंगूठे पहलू अनुपात");
define('MANAGE_GALLERY_SHOW_TITLES', "शो टाइटल");
define('MANAGE_GALLERY_DISABLE_SORT', "अक्षम क्रमबद्ध");
define('MANAGE_GALLERY_DELETE_IMAGE', "छवि को नष्ट");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "सॉर्ट क्रम सहेजें");
define('MANAGE_GALLERY_PUBLISH_MSG', "प्रकाशित करने के लिए क्लिक करें &#39;अपडेट&#39; <br /> अपने अपलोड छवियों।");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "सभी छवियों का आकार बदला गया है और सेटिंग्स बचा लिया गया है।");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "छवियों का आकार बदलने या सेटिंग सहेजने में त्रुटि थी।");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "आपकी छवि (ओं) अपलोड किया गया है।");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "अपनी छवि (ओं) को अपलोड करने में कोई त्रुटि थी।");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "फ़ाइल आप अपलोड करने के लिए कोशिश कर रहे हैं एक छवि नहीं है।");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "फ़ाइल आप अपलोड करने के लिए कोशिश कर रहे हैं बहुत बड़ा है।");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "शीर्षक को बचाया जा चुका है।");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "आप यकीन है कि आप छवि को मिटाना चाहते हैं");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "चित्र को हटा दिया गया है।");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "चित्र को हटाने में कोई त्रुटि थी।");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "मानकों को सहेजना और छवियों का आकार बदलने, कृपया प्रतीक्षा करें ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "अपलोड, कृपया प्रतीक्षा करें ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "सॉर्ट क्रम को सहेजा नहीं गया है। आप सॉर्ट क्रम को बचाने के लिए करना चाहते हैं?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "चित्र को सॉर्ट क्रम को बचाया जा चुका है।");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "छवि की तरह की बचत में कोई त्रुटि थी।");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/hi.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "लाइटबॉक्स गैलरी मापदंडों का प्रबंधन");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "गैलरी प्रबंधित");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "पूर्ण आकार छवि चौड़ाई");
define('MANAGE_GALLERY_FULL_HEIGHT', "पूर्ण आकार छवि ऊंचाई");
define('MANAGE_GALLERY_THUMB_WIDTH', "थंबनेल छवि चौड़ाई");
define('MANAGE_GALLERY_THUMB_HEIGHT', "थंबनेल छवि ऊंचाई");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "रक्षित अंगूठे पहलू अनुपात");
define('MANAGE_GALLERY_SHOW_TITLES', "शो टाइटल");
define('MANAGE_GALLERY_DISABLE_SORT', "अक्षम क्रमबद्ध");
define('MANAGE_GALLERY_DELETE_IMAGE', "छवि को नष्ट");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "सॉर्ट क्रम सहेजें");
define('MANAGE_GALLERY_PUBLISH_MSG', "प्रकाशित करने के लिए क्लिक करें &#39;अपडेट&#39; <br /> अपने अपलोड छवियों।");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "सभी छवियों का आकार बदला गया है और सेटिंग्स बचा लिया गया है।");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "छवियों का आकार बदलने या सेटिंग सहेजने में त्रुटि थी।");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "आपकी छवि (ओं) अपलोड किया गया है।");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "अपनी छवि (ओं) को अपलोड करने में कोई त्रुटि थी।");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "फ़ाइल आप अपलोड करने के लिए कोशिश कर रहे हैं एक छवि नहीं है।");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "फ़ाइल आप अपलोड करने के लिए कोशिश कर रहे हैं बहुत बड़ा है।");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "शीर्षक को बचाया जा चुका है।");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "आप यकीन है कि आप छवि को मिटाना चाहते हैं");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "चित्र को हटा दिया गया है।");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "चित्र को हटाने में कोई त्रुटि थी।");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "मानकों को सहेजना और छवियों का आकार बदलने, कृपया प्रतीक्षा करें ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "अपलोड, कृपया प्रतीक्षा करें ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "सॉर्ट क्रम को सहेजा नहीं गया है। आप सॉर्ट क्रम को बचाने के लिए करना चाहते हैं?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "चित्र को सॉर्ट क्रम को बचाया जा चुका है।");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "छवि की तरह की बचत में कोई त्रुटि थी।");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "आप जिस फ़ाइल को अपलोड करने का प्रयास कर रहे हैं, वह &#39;upload_max_filesize&#39; या &#39;post_max_size&#39; PHP सेटिंग्स से बड़ी है। इन सीमाओं को बढ़ाने के लिए अपने सिस्टम व्यवस्थापक से संपर्क करें।");
?>
